import sys
print(f"输入的参数个数：{len(sys.argv)}")
if len(sys.argv) == 1:
    print("未输入参数，程序退出！")
    sys.exit(0)
else:
    print("程序的输入参数：",end = ' ')
    for item in sys.argv:
        print(item,end = ' ')


from setuptools import setup,find_packages
setup(
    name="ylq-rich",
    version="0.1",
    author="ylq",
    packages = find_packages("src"), # 模块的保存目录
    package_dir = {"":"src"}, # 告诉 setuptools 包都在 ckh 下
    package_data = {
        "":[".txt",".info","*.properties",".py"],
        "":["data/*.*"],
    },
    exclude = ["*.test","*.test.*","test.*","test"]
)